# Some aliases similar to matplotlib.cm
BkRd = "BkRd"
BkGn = "BkGn"
BkBu = "BkBu"
BkCy = "BkCy"
BkMa = "BkMa"
BrBG = "BrBG"
BrOrYl = "BrOrYl"
BuGn = "BuGn"
BuGnYl = "BuGnYl"
BuPu = "BuPu"
BuRd = "BuRd"
GBBr = "GBBr"
GYPi = "GYPi"
GnBu = "GnBu"
GnBuPu = "GnBuPu"
GnRP = "GnRP"
GnYlRd = "GnYlRd"
grayscale = "Grayscale"
GyRd = "GyRd"
Haze = "Haze"
inferno = "Inferno (matplotlib)"
magma = "Magma (matplotlib)"
OrPu = "OrPu"
Oranges = "Oranges"
PrGn = "PRGn"
PiYG = "PiYG"
plasma = "Plasma (matplotlib)"
PuBu = "PuBu"
PuOr = "PuOr"
PuRd = "PuRd"
Purples = "Purples"
RdOr = "RdOr"
RdOrYl = "RdOrYl"
RdPu = "RdPu"
viridis = "Viridis (matplotlib)"
xray = "X Ray"
blot = "blot"
bone = "bone_Matlab"
coolwarm = "coolwarm"
copper = "copper_Matlab"
gist_earch = "gist_earth"
gray = "gray_Matlab"
hsv = "hsv"
jet = "jet"
pink = "pink_Matlab"
rainbow = "rainbow"
